@@ -25,36 +25,38 @@ _LOCK = threading.Lock()
 _INSTRUMENTED_LIBS = set()
 _INSTRUMENT_LIBS_LAZY = set()
 
-INSTRUMENT_LIBS = {
-    "flask": True,
-    "urllib3": True,
-    "celery": True,
-    "pymongo": True,
-    "sqlalchemy": True,
-    "django": True,
-    "redis": True,
-    "pika": True,
-    "cx_Oracle": True,
-    "grpc": True,
-    "ruxit": True,
-    "confluent_kafka": True,
-    "pysnmp": True,
-    "concurrent": True,
-    "urllib": True,
-    "suds": True,
-    "subprocess": True,
-    "paramiko": True,
-}
+INSTRUMENT_LIBS = [
+    "flask",
+    "celery",
+    "pymongo",
+    "sqlalchemy",
+    "django",
+    "redis",
+    "pika",
+    "cx_Oracle",
+    "grpc",
+    "ruxit",
+    "confluent_kafka",
+    "pysnmp",
+    "concurrent",
+    "urllib",
+    "suds",
+    "subprocess",
+    "paramiko",
+]
+
+
+def will_instrument(lib_name):
+    return os.environ.get("AUTODYNATRACE_INSTRUMENT_{}".format(lib_name.upper()), "True").strip().lower() in ("true", "1")
 
 
 def load(_):
     pass
 
 
-def instrument_all(**instrument_libs):
-    libs = INSTRUMENT_LIBS.copy()
-    libs.update(instrument_libs)
-    instrument(**libs)
+def instrument_all():
+    libs = INSTRUMENT_LIBS[:]
+    instrument(libs)
 
 
 def _on_import_wrapper(lib):
@@ -71,24 +73,24 @@ def _on_import_wrapper(lib):
     return on_import
 
 
-def instrument(**instrument_libs):
+def instrument(instrument_libs):
 
-    libs = [l for (l, will_instrument) in instrument_libs.items() if will_instrument]
-    for lib in libs:
+    for lib in instrument_libs:
+        if will_instrument(lib):
 
-        if lib in sys.modules:
-            instrument_lib(lib)
-            _INSTRUMENTED_LIBS.add(lib)
+            if lib in sys.modules:
+                instrument_lib(lib)
+                _INSTRUMENTED_LIBS.add(lib)
 
-        else:
-            when_imported(lib)(_on_import_wrapper(lib))
-            _INSTRUMENT_LIBS_LAZY.add(lib)
+            else:
+                when_imported(lib)(_on_import_wrapper(lib))
+                _INSTRUMENT_LIBS_LAZY.add(lib)
 
     patched_libs = get_already_instrumented()
     lazy_libs = get_will_instrument()
     logger.info(
         "Instrumented {}/{} libraries ({}). Will instrument when imported: ({})".format(
-            len(patched_libs), len(libs), ", ".join(patched_libs), ", ".join(lazy_libs)
+            len(patched_libs), len(instrument_libs), ", ".join(patched_libs), ", ".join(lazy_libs)
         )
     )
 
